Class: SequenceServer::InputError

Inherits:
APIError
  • Object
show all
Defined in:
lib/sequenceserver/api_errors.rb

Overview

Errors caused due to incorrect user input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(more_info) ⇒ InputError

Returns a new instance of InputError.



104
105
106
107
# File 'lib/sequenceserver/api_errors.rb', line 104

def initialize(more_info)
  @more_info = more_info
  super
end

Instance Attribute Details

#more_infoObject (readonly)

Returns the value of attribute more_info.



128
129
130
# File 'lib/sequenceserver/api_errors.rb', line 128

def more_info
  @more_info
end

Instance Method Details

#http_statusObject



109
110
111
# File 'lib/sequenceserver/api_errors.rb', line 109

def http_status
  400
end

#messageObject



117
118
119
120
121
122
123
124
125
126
# File 'lib/sequenceserver/api_errors.rb', line 117

def message
  <<~MSG
    Looks like there's a problem with one of the query sequences, selected
    databases, or advanced parameters. Details of the error are included
    below. Please ask on our
    <a href="https://github.com/wurmlab/sequenceserver/issues" target="_blank">issue tracker</a>
    or on our <a href="https://groups.google.com/g/sequenceserver">forum</a> if you are
    not sure what the error message means, or if the error message is just a number.
  MSG
end

#titleObject



113
114
115
# File 'lib/sequenceserver/api_errors.rb', line 113

def title
  'Input error'
end